# November 27, 2024 - Version 1.6.2

Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.6.2
```


If you prefer to use Anaconda, please install PrismStudio using command below

```bash
conda config --add channels conda-forge
conda install -c prism39 prismstudio
```


---

## Change Log
- Added Economics component in PrismStudio! (ps.economics.economics)
- Added Datastream Economics Package
- Renamed packagename Old: "LSEG Financials Significant Developments" New: "LSEG Significant Developments"
- Renamed packagename Old: "LSEG Financials Business Description" New: "LSEG Business Description"
- Fixed minor bugs in CIQ Alpha Factor Library

